notetools.make_quarter_notes_with_lilypond_duration_multiplier
==============================================================

.. autofunction:: abjad.tools.notetools.make_quarter_notes_with_lilypond_duration_multiplier.make_quarter_notes_with_lilypond_duration_multiplier
